Package: auth0
Type: Package
Title: Authentication in Shiny with Auth0
Version: 0.3.0
Authors@R: c(
    person("Julio", "Trecenti", email = "julio.trecenti@gmail.com", role = "cre"),
    person("Daniel", "Falbel", email = "dfalbel@gmail.com", role = "aut"),
    person("José", "Jesus", email = "jjesusfilho@gmail.com", role = "ctb"),
    person("Dean", "Attali", email = "daattali@gmail.com", role = "ctb"),
    person("William", "Amorim", email = "TheWilliam89@gmail.com", role = "ctb"),
    person("C", "Lente", email = "c@lente.dev", role = "ctb"))
Description: Uses Auth0 API (see <https://auth0.com> for more 
    information) to use a simple authentication system. It provides 
    tools to log in and out a shiny application using social networks or a list
    of e-mails.
BugReports: https://github.com/curso-r/auth0/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: httr, shiny, yaml, utils, shinyjs
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
URL: https://curso-r.github.io/auth0/
NeedsCompilation: no
Packaged: 2026-04-13 16:37:49 UTC; jtrec
Author: Julio Trecenti [cre],
  Daniel Falbel [aut],
  José Jesus [ctb],
  Dean Attali [ctb],
  William Amorim [ctb],
  C Lente [ctb]
Maintainer: Julio Trecenti <julio.trecenti@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-13 19:20:09 UTC
Built: R 4.5.2; ; 2026-04-15 05:07:46 UTC; unix
