---
title: "ui-server-bookmark"
type: docs
repo: https://github.com/curso-r/auth0
menu:
  main:
    parent: examples
---

<div class="source-ref">
<span class="caption">Source: </span>`r sprintf("https://github.com/curso-r/auth0/blob/master/inst/%s", rmarkdown::metadata$title)`
</div>

Don't forget to configure your environment variables. 

Also, set the port, running something like `options(shiny.port = 8080)`.

## ui.R

```{r, echo = FALSE}
knitr::opts_chunk$set(eval = FALSE)

f <- system.file(sprintf("%s/ui.R", rmarkdown::metadata$title), package = "auth0")
knitr::spin_child(f)
```

## server.R

```{r, echo = FALSE, eval=TRUE}
knitr::opts_chunk$set(eval = FALSE)

f <- system.file(sprintf("%s/server.R", rmarkdown::metadata$title), package = "auth0")
knitr::spin_child(f)
```

## _auth0.yml

```{r, echo = FALSE, eval=TRUE, comment=NA}
f <- system.file(sprintf("%s/_auth0.yml", rmarkdown::metadata$title), package = "auth0")
cat(readLines(f), sep = "\n")
```

